@@ -12,7 +12,7 @@ our @ISA = qw(Exporter);
 
 our @EXPORT = qw( parameters );
 
-our $VERSION = '1.03_1';
+our $VERSION = '1.04_1';	# TRIAL
 
 =head1 NAME
 
@@ -127,7 +127,7 @@ C<parameters> will die.
 The final argument to C<parameters> is always the list of arguments passed to
 the caller, usually C<@_>.
 
-=head2 RESULTS
+=head2 Results
 
 The result returned from the C<parameters> function depends on whether there
 are two arguments or three. If C<parameters> is called with two arguments,
@@ -136,7 +136,7 @@ three arguments, then an invocant is prepended to the list of pairs first.
 If the first argument is not C<"self">, then the invocant will be set to the
 first argument if C<parameters> doesn't detect any invocant.
 
-=head2 ARGUMENT PARSING
+=head1 ARGUMENT PARSING
 
 The way C<parameters> handles arguments is relatively flexible. However, the
 format must always specify all positional parameters first, if any, followed by
@@ -165,7 +165,7 @@ sub parameters {
 	}
 
 	croak "Getopt::Mixed specification contains more than one semicolon."
-			if grep /;/, @$spec > 1;
+			if grep(/;/, @$spec) > 1;
 
 	# Extract invocant
 	my $self;
@@ -185,17 +185,18 @@ sub parameters {
 	my @required;
 	for (0 .. $#$spec) {
 		last if $$spec[$_] eq '*';
+
 		if ($$spec[$_] eq ';') {
 			splice(@$spec, $_, 1);
 
 			last;
-		} elsif ($$spec[$_] =~ /;/) {
-			my @els = split /;/, $$spec[$_];
-			shift @els if $els[0] eq '';
 
-			croak "Getopt::Mixed specification contains more than one semicolon."
+		} elsif ($$spec[$_] =~ /;/) {
+			my @els = split /;/, $$spec[$_], -1;	# -1 => keep empty fields
+			croak "Getopt::Mixed specification contains multiple semicolons."
 					if @els > 2;
 
+			shift @els if @els and $els[0] eq '';	# semicolon first
 			push @required, $els[0] unless $$spec[$_] =~ /^;/;
 			splice(@$spec, $_, 1, @els);
 
@@ -205,7 +206,6 @@ sub parameters {
 		push @required, $$spec[$_];
 	}
 
-
 	my %result;
 
 	# Scan for positional parameters
@@ -245,7 +245,7 @@ sub parameters {
 	return defined $self ? ($self, %result) : %result;
 } #parameters()
 
-=head2 EXPORT
+=head1 EXPORT
 
 Always exports C<parameters> by default. If you do not want this, use:
 
@@ -269,13 +269,27 @@ C<parameters> is called as a function.
 
 =head2 new
 
-Create a new instance with the given options.  Currently known options are:
+Create a new instance with the given options.  For example:
+
+  my $getargs = Getargs::Mixed->new(-undef_ok => 1);
+
+Currently known options are:
 
 =over
 
 =item -undef_ok
 
-The option C<< -undef_ok => 1 >> permits option values to be C<undef>.
+The option C<< -undef_ok => 1 >> permits the value of a parameter to be
+C<undef>.  For example,
+
+  my %args = parameters(['foo'], -foo => undef);
+
+will fail with a message that required argument C<foo> was not provided, but
+
+    my %args = Getargs::Mixed->new(-undef_ok => 1)
+                             ->parameters(['foo'], -foo => undef);
+
+will succeed, and set C<< $args{foo} >> to C<undef>.
 
 =back
 
